@@ -63,7 +63,8 @@ typedef enum {
     IGFX_ICELAKE,
     IGFX_ICELAKE_LP,
     IGFX_LAKEFIELD,
-    IGFX_ELKHARTLAKE,
+    IGFX_JASPERLAKE,
+    IGFX_ELKHARTLAKE     =IGFX_JASPERLAKE,
     IGFX_TIGERLAKE_LP,
     IGFX_MAX_PRODUCT,
 
@@ -1177,6 +1178,9 @@ typedef enum __NATIVEGTTYPE
 #define ILKF_1x6x8_DESK_DEVICE_F0_ID            0x9841
 #define ILKF_1x4x8_DESK_DEVICE_F0_ID            0x9842
 
+//JSL
+#define IJSL_1x4x8_DEVICE_A0_ID                 0x4500
+
 //EHL
 #define IEHL_1x4x8_SUPERSKU_DEVICE_A0_ID        0x4500
 #define IEHL_1x2x4_DEVICE_A0_ID                 0x4541
